<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_TW" version="2.1">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&lt;h2&gt;%1 Client %2&lt;/h2&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&lt;h5&gt; REV %1 &lt;/h5&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>About</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Check For Updates</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AccountManager</name>
    <message>
        <source>failed to open account database</source>
        <translation>無法開啟帳號數據庫</translation>
    </message>
    <message>
        <source>Authorization expired, please re-login</source>
        <translation>帳號驗證訊息已過期，請重新登入</translation>
    </message>
    <message>
        <source>Failed to remove local repos sync token: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to get repo sync information from server: %1</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AccountSettingsDialog</name>
    <message>
        <source>Account Settings</source>
        <translation>帳號設定</translation>
    </message>
    <message>
        <source>Please enter the server address</source>
        <translation>請輸入伺服器位置</translation>
    </message>
    <message>
        <source>%1 is not a valid server address</source>
        <translation>％1 不是有效的伺服器位置</translation>
    </message>
    <message>
        <source>Failed to save account information</source>
        <translation>無法存儲帳號訊息</translation>
    </message>
    <message>
        <source>Failed to save the changes: %1</source>
        <translation>無法儲存以下更改： %1</translation>
    </message>
    <message>
        <source>Successfully updated current account information</source>
        <translation>成功更新目前帳號訊息</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>對話框</translation>
    </message>
    <message>
        <source>Server Address</source>
        <translation>伺服器位置</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>電子郵件</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>確認</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
</context>
<context>
    <name>AccountView</name>
    <message>
        <source>Are you sure you want to remove account %1?&lt;br&gt;&lt;br&gt;The account will be removed locally. All syncing configuration will be removed too. The account at the server will not be affected.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to unsync libraries of this account: %1</source>
        <translation>無法解除同步此帳號下的資料庫 %1</translation>
    </message>
    <message>
        <source>click to open the website</source>
        <translation>開啟檢視網頁端</translation>
    </message>
    <message>
        <source>pro version</source>
        <translation>專業版</translation>
    </message>
    <message>
        <source>No account</source>
        <translation>沒有可用帳號</translation>
    </message>
    <message>
        <source>Choose</source>
        <translation>選擇</translation>
    </message>
    <message>
        <source>Account settings</source>
        <translation>帳號設定</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>登入</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <source>Add an account</source>
        <translation>增加新的帳號</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>登出</translation>
    </message>
    <message>
        <source>not logged in</source>
        <translation>尚未登陸</translation>
    </message>
    <message>
        <source>Form</source>
        <translation>表單</translation>
    </message>
    <message>
        <source>Account</source>
        <translation>帳號</translation>
    </message>
    <message>
        <source>email</source>
        <translation>電子郵件</translation>
    </message>
    <message>
        <source>server</source>
        <translation>伺服器</translation>
    </message>
</context>
<context>
    <name>ActivitiesTab</name>
    <message>
        <source>File Activities are only supported in %1 Server Professional Edition.</source>
        <translation>很抱歉，但是此功能只在 %1 專業版本提供支援</translation>
    </message>
    <message>
        <source>retry</source>
        <translation>重新嘗試</translation>
    </message>
    <message>
        <source>Failed to get actvities information. Please %1</source>
        <translation>無法獲取變動資訊，請 %1</translation>
    </message>
</context>
<context>
    <name>AutoUpdateManager</name>
    <message>
        <source>Upload Success</source>
        <translation>上傳成功</translation>
    </message>
    <message>
        <source>File &quot;%1&quot;
uploaded successfully.</source>
        <translation>檔案 &quot;%1&quot;
成功上傳。</translation>
    </message>
    <message>
        <source>File &quot;%1&quot;
failed to upload.</source>
        <translation>檔案 &quot;%1&quot;
無法上傳。</translation>
    </message>
    <message>
        <source>Permission Error!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Authorization expired</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File does not exist</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The file is locked by %1, please try again later</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Upload Failure: %1</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AvatarService</name>
    <message>
        <source>Failed to create avatars folder</source>
        <translation>無法建立大頭照資料夾</translation>
    </message>
</context>
<context>
    <name>CheckRepoRootDirPermDialog</name>
    <message>
        <source>Checking Permission</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CloneTasksDialog</name>
    <message>
        <source>Download tasks</source>
        <translation>下載任務</translation>
    </message>
    <message>
        <source>remove all successful tasks</source>
        <translation>刪除所有已完成的任務</translation>
    </message>
    <message>
        <source>No download tasks right now.</source>
        <translation>目前沒有下載任務</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>對話框</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>清除</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>關閉</translation>
    </message>
</context>
<context>
    <name>CloneTasksTableModel</name>
    <message>
        <source>Library</source>
        <translation>資料庫</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>路徑</translation>
    </message>
</context>
<context>
    <name>CloneTasksTableView</name>
    <message>
        <source>Cancel this task</source>
        <translation>取消這項任務</translation>
    </message>
    <message>
        <source>cancel this task</source>
        <translation>取消這項任務</translation>
    </message>
    <message>
        <source>Remove this task</source>
        <translation>刪除這項任務</translation>
    </message>
    <message>
        <source>Failed to cancel this task:

 %1</source>
        <translation>無法取消這項任務：

%1</translation>
    </message>
    <message>
        <source>Failed to remove this task:

 %1</source>
        <translation>無法刪除這項任務：

%1</translation>
    </message>
</context>
<context>
    <name>CloudView</name>
    <message>
        <source>Minimize</source>
        <translation>視窗最小化</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>關閉</translation>
    </message>
    <message>
        <source>Libraries</source>
        <translation>資料庫</translation>
    </message>
    <message>
        <source>Starred</source>
        <translation>標示</translation>
    </message>
    <message>
        <source>Activities</source>
        <translation>事件</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>檢索</translation>
    </message>
    <message>
        <source>current download rate</source>
        <translation>目前下載速率</translation>
    </message>
    <message>
        <source>current upload rate</source>
        <translation>目前上載速率</translation>
    </message>
    <message>
        <source>Please Choose a folder to sync</source>
        <translation>請選擇空閒目錄以用於同步</translation>
    </message>
    <message>
        <source>no server connected</source>
        <translation>沒有到伺服器的連接</translation>
    </message>
    <message>
        <source>all servers connected</source>
        <translation>到伺服器的連接正常運作中</translation>
    </message>
    <message>
        <source>some servers not connected</source>
        <translation>到伺服器的鏈路部分運作中</translation>
    </message>
    <message>
        <source>Form</source>
        <translation>表單</translation>
    </message>
    <message>
        <source>logo</source>
        <translation>圖示</translation>
    </message>
    <message>
        <source>minimize</source>
        <translation>視窗最小化</translation>
    </message>
    <message>
        <source>close</source>
        <translation>關閉</translation>
    </message>
    <message>
        <source>...</source>
        <translation>更多</translation>
    </message>
    <message>
        <source>Select</source>
        <translation>選擇</translation>
    </message>
    <message>
        <source>brand</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>or Drop Folder to Sync</source>
        <translation>或者拖拽目錄到此處 進行同步</translation>
    </message>
    <message>
        <source>download rate</source>
        <translation>下載速率</translation>
    </message>
    <message>
        <source>downarrow</source>
        <translation>向下箭頭</translation>
    </message>
    <message>
        <source>upload rate</source>
        <translation>上傳速率</translation>
    </message>
    <message>
        <source>uparrow</source>
        <translation>向上箭頭</translation>
    </message>
</context>
<context>
    <name>Configurator</name>
    <message>
        <source>Error when creating ccnet configuration</source>
        <translation>在建立ccnet設定檔案時候遭遇錯誤</translation>
    </message>
    <message>
        <source>Unable to create preconfigure directory &quot;%1&quot;</source>
        <translation>無法建立預配置資料夾 &quot;%1&quot;</translation>
    </message>
    <message>
        <source>failed to read %1</source>
        <translation>無法讀取 %1</translation>
    </message>
</context>
<context>
    <name>CreateRepoDialog</name>
    <message>
        <source>Create a library</source>
        <translation>建立新的資料庫</translation>
    </message>
    <message>
        <source>Please choose a directory</source>
        <translation>請選擇空閒目錄以用於同步</translation>
    </message>
    <message>
        <source>Creating...</source>
        <translation>建立 ...</translation>
    </message>
    <message>
        <source>Failed to generate encryption key for this library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please choose the directory to sync</source>
        <translation>請選擇空閒目錄以用於同步</translation>
    </message>
    <message>
        <source>The folder %1 does not exist</source>
        <translation>目錄 %1 不存在</translation>
    </message>
    <message>
        <source>Please enter the name</source>
        <translation>請輸入名稱</translation>
    </message>
    <message>
        <source>Please enter the password</source>
        <translation>請輸入保護密碼</translation>
    </message>
    <message>
        <source>Passwords don&apos;t match</source>
        <translation>密碼無法匹配</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>遭遇未知錯誤</translation>
    </message>
    <message>
        <source>Failed to add download task:
 %1</source>
        <translation>無法增加新的下載任務：
%1</translation>
    </message>
    <message>
        <source>Failed to create library on the server:
%1</source>
        <translation>無法在伺服器上建立新的資料庫：
%1</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>對話框</translation>
    </message>
    <message>
        <source>Path:</source>
        <translation>路徑：</translation>
    </message>
    <message>
        <source>Choose</source>
        <translation>選擇</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>名稱：</translation>
    </message>
    <message>
        <source>encrypted</source>
        <translation>已加密</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>密碼：</translation>
    </message>
    <message>
        <source>Password Again:</source>
        <translation>重複密碼：</translation>
    </message>
    <message>
        <source>status text</source>
        <translation>狀態文字</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>確認</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
</context>
<context>
    <name>DaemonManager</name>
    <message>
        <source>failed to load ccnet config dir %1</source>
        <translation>無法載入ccnet的配置目錄 %1</translation>
    </message>
    <message>
        <source>%1 client failed to initialize</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DownloadRepoDialog</name>
    <message>
        <source>Please enter the password</source>
        <translation>請輸入保護密碼</translation>
    </message>
    <message>
        <source>Sync library &quot;%1&quot;</source>
        <translation>同步資料庫 %1</translation>
    </message>
    <message>
        <source>Sync folder &quot;%1&quot;</source>
        <translation>同步目錄 &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Sync to folder:</source>
        <translation>同步到資料夾：</translation>
    </message>
    <message>
        <source>or</source>
        <translation>或著</translation>
    </message>
    <message>
        <source>sync with an existing folder</source>
        <translation>於已有的資料夾同步</translation>
    </message>
    <message>
        <source>create a new sync folder</source>
        <translation>創建一個新的同步資料夾</translation>
    </message>
    <message>
        <source>Sync with this existing folder:</source>
        <translation>與這個已存在的資料夾同步：</translation>
    </message>
    <message>
        <source>Please choose a folder</source>
        <translation>請選擇一個資料夾</translation>
    </message>
    <message>
        <source>The folder does not exist</source>
        <translation>此資料夾不存在</translation>
    </message>
    <message>
        <source>Please choose the folder to sync.</source>
        <translation>請選擇一個用於同步的資料夾。</translation>
    </message>
    <message>
        <source>Your organization disables putting a library outside %1 folder.</source>
        <translation>您的組織已經屏蔽將資料庫同步於 %1 目錄外的功能。</translation>
    </message>
    <message>
        <source>Conflicting with existing file &quot;%1&quot;, please choose a different folder.</source>
        <translation>與已有檔案 &quot;%1&quot; 發生衝突，請選擇其他資料夾。</translation>
    </message>
    <message>
        <source>Conflicting with existing library &quot;%1&quot;, please choose a different folder.</source>
        <translation>與已有的資料庫 &quot;%1&quot; 發生衝突，請選擇其他資料夾。</translation>
    </message>
    <message>
        <source>The folder &quot;%1&quot; already exists. Are you sure to sync with it (contents will be merged)?</source>
        <translation>資料夾 &quot;%1&quot; 已經存在。 請問您是否與之同步 (內容會被合併) ?</translation>
    </message>
    <message>
        <source>Click No to sync with a new folder instead</source>
        <translation>點擊“否” 則與一個新的資料夾同步</translation>
    </message>
    <message>
        <source>Unable to find an alternative folder name</source>
        <translation>無法找到其他合適的資料夾名稱</translation>
    </message>
    <message>
        <source>Failed to add download task:
 %1</source>
        <translation>無法增加新的下載任務：
%1</translation>
    </message>
    <message>
        <source>Failed to get repo download information:
%1</source>
        <translation>無法獲取資料庫的下載檔案：
%1</translation>
    </message>
    <message>
        <source>Download Library</source>
        <translation>下載資料庫</translation>
    </message>
    <message>
        <source>choose...</source>
        <translation>選取...</translation>
    </message>
    <message>
        <source>Password for this library:</source>
        <translation>此資料庫的密碼：</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>確認</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
</context>
<context>
    <name>EventDetailsDialog</name>
    <message>
        <source>Modification Details</source>
        <translation>詳細的修改差異集</translation>
    </message>
</context>
<context>
    <name>EventDetailsListModel</name>
    <message>
        <source>Added files</source>
        <translation>已添加的檔案</translation>
    </message>
    <message>
        <source>Deleted files</source>
        <translation>已刪除的檔案</translation>
    </message>
    <message>
        <source>Modified files</source>
        <translation>已修改的檔案</translation>
    </message>
    <message>
        <source>Added folders</source>
        <translation>已添加的資料夾</translation>
    </message>
    <message>
        <source>Deleted folders</source>
        <translation>已刪除的資料夾</translation>
    </message>
</context>
<context>
    <name>EventDetailsListView</name>
    <message>
        <source>&amp;Open</source>
        <translation>打開(&amp;O)
</translation>
    </message>
    <message>
        <source>Open &amp;parent folder</source>
        <translation>打開父資料夾(&amp;P)</translation>
    </message>
</context>
<context>
    <name>FileBrowserDialog</name>
    <message>
        <source>Cloud File Browser</source>
        <translation>雲端檔案瀏覽器</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>回退</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>前進</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>根目錄</translation>
    </message>
    <message>
        <source>Upload files</source>
        <translation>上傳多個檔案</translation>
    </message>
    <message>
        <source>Upload a directory</source>
        <translation>上傳目錄</translation>
    </message>
    <message>
        <source>You don&apos;t have permission to upload files to this library</source>
        <translation>您沒有權限上傳檔案到這個資料庫</translation>
    </message>
    <message>
        <source>Create a folder</source>
        <translation>新建目錄</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 items</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Folder name</source>
        <translation>資料夾名稱</translation>
    </message>
    <message>
        <source>Invalid folder name!</source>
        <translation>無效的目錄名稱！</translation>
    </message>
    <message>
        <source>The name &quot;%1&quot; is already taken.</source>
        <translation>名稱 &quot;%1&quot; 已經被佔用了。</translation>
    </message>
    <message>
        <source>retry</source>
        <translation>重新嘗試</translation>
    </message>
    <message>
        <source>Failed to get files information&lt;br/&gt;Please %1</source>
        <translation>無法獲取檔案訊息&lt;br/&gt;
請 %1</translation>
    </message>
    <message>
        <source>This folder is empty.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enter name of file to save to...</source>
        <translation>請輸入需要另存為的檔案名稱...</translation>
    </message>
    <message>
        <source>Unable to remove file &quot;%1&quot;</source>
        <translation>無法刪除檔案 &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Enter the path of the folder you want to save to...</source>
        <translation>請輸入需要另存到的資料檔的路徑...</translation>
    </message>
    <message>
        <source>Do you want to overwrite the existing file &quot;%1&quot;?</source>
        <translation>您真的想刪除已有檔案 &quot;%1&quot; 嗎？</translation>
    </message>
    <message>
        <source>File &quot;%1&quot; haven&apos;t been synced</source>
        <translation>檔案 &quot;%1&quot; 沒有被同步</translation>
    </message>
    <message>
        <source>File %1 already exists.&lt;br/&gt;Do you like to overwrite it?&lt;br/&gt;&lt;small&gt;(Choose No to upload using an alternative name).&lt;/small&gt;</source>
        <translation>檔案 %1 已經存在。&lt;br/&gt;您想覆蓋它嗎？&lt;br/&gt;&lt;small&gt;（選 否 會使用不同的名字）。&lt;/small&gt;</translation>
    </message>
    <message>
        <source>File does not exist</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to download file: %1</source>
        <translation>無法下載檔案：%1</translation>
    </message>
    <message>
        <source>Select a file to upload</source>
        <translation>請選擇需要上傳的檔案</translation>
    </message>
    <message>
        <source>Select a directory to upload</source>
        <translation>選擇你需要上傳的目錄</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>重命名</translation>
    </message>
    <message>
        <source>Do you really want to delete these items</source>
        <translation>您真的想刪除這些檔案嗎？</translation>
    </message>
    <message>
        <source>Create folder failed</source>
        <translation>建立目錄失敗</translation>
    </message>
    <message>
        <source>Lock file failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Select a file to update %1</source>
        <translation>請選擇需要上傳的檔案 以更新 %1</translation>
    </message>
    <message>
        <source>Rename failed</source>
        <translation>重命名失敗</translation>
    </message>
    <message>
        <source>Remove failed</source>
        <translation>刪除失敗</translation>
    </message>
    <message>
        <source>Share failed</source>
        <translation>分享失敗</translation>
    </message>
    <message>
        <source>Cannot paste files from the same folder</source>
        <translation>無法從相同的目錄拷貝檔案</translation>
    </message>
    <message>
        <source>Cannot paste the folder to its subfolder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Copy failed</source>
        <translation>複製失敗</translation>
    </message>
    <message>
        <source>Move failed</source>
        <translation>移動失敗</translation>
    </message>
    <message>
        <source>Create library failed!</source>
        <translation>建立目錄失敗!</translation>
    </message>
    <message>
        <source>You do not have permission to upload to this folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Authorization expired</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Permission Error!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library/Folder not found.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to upload file %1: %2</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to create cache folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to open cache folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Search files</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FileBrowserProgressDialog</name>
    <message>
        <source>Pending</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>上傳</translation>
    </message>
    <message>
        <source>Uploading %1</source>
        <translation>正在上傳 %1</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>下載</translation>
    </message>
    <message>
        <source>Downloading %1</source>
        <translation>正在下載 %1</translation>
    </message>
    <message>
        <source>%1 of %2</source>
        <translation>已完成 %2 中的 %1</translation>
    </message>
    <message>
        <source>Failed to upload file &quot;%1&quot;, do you want to retry?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Retry</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Skip</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Abort</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Saving</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File save failed</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FileBrowserSearchModel</name>
    <message>
        <source>Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Size</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Last Modified</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Kind</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FileBrowserSearchView</name>
    <message>
        <source>&amp;Show in folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show in folder</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FileNetworkTask</name>
    <message>
        <source>Operation canceled</source>
        <translation>操作已取消</translation>
    </message>
    <message>
        <source>pending</source>
        <translation>等待中</translation>
    </message>
</context>
<context>
    <name>FileServerTask</name>
    <message>
        <source>task cancelled</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Internal Server Error</source>
        <translation>內部伺服器錯誤</translation>
    </message>
    <message>
        <source>The storage quota has been used up</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FileTableModel</name>
    <message>
        <source>locked by %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Name</source>
        <translation>名稱</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>檔案大小</translation>
    </message>
    <message>
        <source>Last Modified</source>
        <translation>最後修改日期</translation>
    </message>
    <message>
        <source>Kind</source>
        <translation>類型</translation>
    </message>
</context>
<context>
    <name>FileTableView</name>
    <message>
        <source>&amp;Save As...</source>
        <translation>另存為... (&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Lock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Rename</source>
        <translation>重命名(&amp;R)</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>刪除(&amp;D)</translation>
    </message>
    <message>
        <source>Share to Group</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Update</source>
        <translation>更新(&amp;U)</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>複製 (&amp;C)</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>剪貼 (&amp;T)</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>粘貼 (&amp;P)</translation>
    </message>
    <message>
        <source>Canc&amp;el Download</source>
        <translation>取消下載(&amp;C)</translation>
    </message>
    <message>
        <source>&amp;Sync this folder</source>
        <translation>同步此資料夾 (&amp;S)</translation>
    </message>
    <message>
        <source>This feature is available in pro version only
</source>
        <translation>此功能只在專業版中提供</translation>
    </message>
    <message>
        <source>&amp;Generate %1 Download Link</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Share to User</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>G&amp;enerate %1 Internal Link</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Save As To...</source>
        <translation>另存到... (&amp;S)</translation>
    </message>
    <message>
        <source>Un&amp;lock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to remove readonly files</source>
        <translation>無法刪除只讀文件</translation>
    </message>
    <message>
        <source>Unable to cut readonly files</source>
        <translation>無法剪切只讀文件</translation>
    </message>
    <message>
        <source>Retry Upload</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delete Local Version</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Local Version Save As...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open Local Cache Folder</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GetFileTask</name>
    <message>
        <source>Failed to create folders</source>
        <translation>無法建立資料夾</translation>
    </message>
    <message>
        <source>Failed to create temporary files</source>
        <translation>無法建立臨時檔案</translation>
    </message>
    <message>
        <source>Failed to write file to disk</source>
        <translation>無法將檔案寫入磁盤</translation>
    </message>
    <message>
        <source>Failed to remove the older version of the downloaded file</source>
        <translation>無法刪除已下載的檔案</translation>
    </message>
    <message>
        <source>Failed to move file</source>
        <translation>無法刪除檔案</translation>
    </message>
</context>
<context>
    <name>InitSeafileDialog</name>
    <message>
        <source>%1 Initialization</source>
        <translation>%1 還在初始化</translation>
    </message>
    <message>
        <source>Choose %1 folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please choose a directory</source>
        <translation>請選擇空閒目錄以用於同步</translation>
    </message>
    <message>
        <source>Initialization is not finished. Really quit?</source>
        <translation>初始化還沒有完成，確認現在退出？</translation>
    </message>
    <message>
        <source>The folder %1 does not exist</source>
        <translation>目錄 %1 並不存在</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>對話框</translation>
    </message>
    <message>
        <source>logo</source>
        <translation>圖示</translation>
    </message>
    <message>
        <source>Choose a folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please choose a folder. We will create a %1 subfolder in it. When you download a library, it will be saved there by default.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Choose...</source>
        <translation>選取...</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>下一步</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
</context>
<context>
    <name>InitVirtualDriveDialog</name>
    <message>
        <source>%1 organizes files by libraries.
Do you like to download your default library?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Checking your default library...</source>
        <translation>正在檢查您的默認資料庫...</translation>
    </message>
    <message>
        <source>Creating the default library...</source>
        <translation>正在建立默認資料庫...</translation>
    </message>
    <message>
        <source>Failed to create default library:

The server version must be 2.1 or higher to support this.</source>
        <translation>無法建立默認資料庫：

此項功能只在伺服器版本2.1或者之上被支援</translation>
    </message>
    <message>
        <source>Failed to get default library:
%1</source>
        <translation>無法取得默認資料庫：
%1</translation>
    </message>
    <message>
        <source>Failed to create default library:
%1</source>
        <translation>無法建立默認資料庫：
%1</translation>
    </message>
    <message>
        <source>Downloading default library...</source>
        <translation>正在下載默認資料庫...</translation>
    </message>
    <message>
        <source>Failed to download default library:
%1</source>
        <translation>無法下載默認資料庫：
%1</translation>
    </message>
    <message>
        <source>The default library has been downloaded.
You can click the &quot;Open&quot; button to view it.</source>
        <translation>默認資料庫已下載完畢。
您可以點擊“開啟”查看。</translation>
    </message>
    <message>
        <source>Error when downloading the default library: %1</source>
        <translation>在下載默認資料庫的時候遭遇錯誤：%1</translation>
    </message>
    <message>
        <source>Failed to download default library:
 %1</source>
        <translation>無法下載默認資料庫：
%1</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>對話框</translation>
    </message>
    <message>
        <source>%1 organizes files by libraries. 
Do you like to download your default library?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Skip</source>
        <translation>略過</translation>
    </message>
    <message>
        <source>Run in Background</source>
        <translation>後台模式運行</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>開啟</translation>
    </message>
    <message>
        <source>Finish</source>
        <translation>完結</translation>
    </message>
    <message>
        <source>Download Default Library</source>
        <translation>下載默認資料庫</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>好</translation>
    </message>
    <message>
        <source>logo</source>
        <translation>圖示</translation>
    </message>
</context>
<context>
    <name>LoadMoreButton</name>
    <message>
        <source>load more</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LoginDialog</name>
    <message>
        <source>Add an account</source>
        <translation>增加新的帳號</translation>
    </message>
    <message>
        <source>Single Sign On</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Re-login</source>
        <translation>重新登陸</translation>
    </message>
    <message>
        <source>Logging in...</source>
        <translation>登入中...</translation>
    </message>
    <message>
        <source>Network Error:
 %1</source>
        <translation>網路錯誤：
%1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Warning:&lt;/b&gt; The ssl certificate of this server is not trusted, proceed anyway?</source>
        <translation>&lt;b&gt;警告：&lt;/b&gt; 伺服器的SSL證書不被信任，請問還需要繼續操作嗎？</translation>
    </message>
    <message>
        <source>Please enter the server address</source>
        <translation>請輸入伺服器地址</translation>
    </message>
    <message>
        <source>%1 is not a valid server address</source>
        <translation>％1 不是有效的伺服器地址</translation>
    </message>
    <message>
        <source>Please enter the username</source>
        <translation>請輸入用戶名</translation>
    </message>
    <message>
        <source>Please enter the computer name</source>
        <translation>請輸入此計算機的代號</translation>
    </message>
    <message>
        <source>Failed to save current account</source>
        <translation>無法儲存目前帳號</translation>
    </message>
    <message>
        <source>%1 Server Address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Server address must not be empty</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 is not a valid server address. It has to start with &apos;https://&apos;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please enter the password</source>
        <translation>請輸入保護密碼</translation>
    </message>
    <message>
        <source>Incorrect email or password</source>
        <translation>無法理解的郵件地址或者密碼</translation>
    </message>
    <message>
        <source>Logging in too frequently, please wait a minute</source>
        <translation>嘗試展登入過於頻繁，請稍後嘗試</translation>
    </message>
    <message>
        <source>Internal Server Error</source>
        <translation>內部伺服器錯誤</translation>
    </message>
    <message>
        <source>Failed to login: %1</source>
        <translation>無法登入：%1</translation>
    </message>
    <message>
        <source>Failed to login</source>
        <translation>無法登入</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>對話框</translation>
    </message>
    <message>
        <source>logo</source>
        <translation>圖示</translation>
    </message>
    <message>
        <source>Server:</source>
        <translation>伺服器：</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;For example: https://seacloud.cc&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;比如 https://seacloud.cc &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>or http://192.168.1.24:8000</source>
        <translation>或者 http://192.168.1.24:8000</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>密碼：</translation>
    </message>
    <message>
        <source>status text</source>
        <translation>狀態文字</translation>
    </message>
    <message>
        <source>Computer Name:</source>
        <translation>計算機代號：</translation>
    </message>
    <message>
        <source>Email / Username:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>e.g. Jim&apos;s laptop</source>
        <translation>比如 Jim 的本本</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>登入</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>Automatic Login</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LogoutView</name>
    <message>
        <source>You are logout. Please </source>
        <translation>您已登出。請</translation>
    </message>
    <message>
        <source>login</source>
        <translation>登入</translation>
    </message>
    <message>
        <source>Add an account</source>
        <translation>增加新的帳號</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Refresh</source>
        <translation>重新整理</translation>
    </message>
</context>
<context>
    <name>MessageListener</name>
    <message>
        <source>failed to load ccnet config dir </source>
        <translation>無法載入ccnet的配置目錄</translation>
    </message>
    <message>
        <source>&quot;%1&quot; is unsynced. 
Reason: Deleted on server</source>
        <translation>”%1” 沒有被同步。
因為... 已被伺服器刪除</translation>
    </message>
    <message>
        <source>&quot;%1&quot; is synchronized</source>
        <translation>“%1&quot; 同步完成</translation>
    </message>
    <message>
        <source>Files uploaded to &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File %1 conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to sync file %1
File is locked by other application. This file will be updated when you close the application.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to sync folder %1
Some file in this folder is locked by other application. This folder will be updated when you close the application.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to sync %1
File path is ended with space or period and cannot be created on Windows.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to sync %1
File path contains invalid characters. It is not synced to this computer.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to index file %1
Please check file permission and disk space.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&quot;%1&quot; failed to sync. 
Access denied to service</source>
        <translation>&quot;%1&quot; 無法同步。
因為... 被伺服器拒絕</translation>
    </message>
    <message>
        <source>&quot;%1&quot; failed to sync.
The library owner&apos;s storage space is used up.</source>
        <translation>&quot;%1&quot; 無法同步。
因為... 用盡配額了= =</translation>
    </message>
    <message>
        <source>Update to file %1 is denied by folder permission setting.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to sync file %1
File is locked by another user. Update to this file is not uploaded.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PrivateShareDialog</name>
    <message>
        <source>Share %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enter the group name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enter user name or email address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Updated successfully</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Share Operation Failed: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Removed successfully</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to get share information of the folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to get your groups and contacts information</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please enter the username</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please enter the group name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No such group &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Already shared to group %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Already shared to user %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The previous operation is still in progres</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dialog</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Share To:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Share</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Permission:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Read-Write</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Read-Only</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>synchronized</source>
        <translation>已同步</translation>
    </message>
    <message>
        <source>indexing files</source>
        <translation>正在索引檔案</translation>
    </message>
    <message>
        <source>sync initializing</source>
        <translation>同步初始化完畢</translation>
    </message>
    <message>
        <source>downloading</source>
        <translation>正在下載</translation>
    </message>
    <message>
        <source>uploading</source>
        <translation>正在上傳</translation>
    </message>
    <message>
        <source>sync merging</source>
        <translation>同步合併中</translation>
    </message>
    <message>
        <source>waiting for sync</source>
        <translation>等待同步中</translation>
    </message>
    <message>
        <source>server not connected</source>
        <translation>沒有接入伺服器</translation>
    </message>
    <message>
        <source>server authenticating</source>
        <translation>正在和伺服器驗證身份</translation>
    </message>
    <message>
        <source>auto sync is turned off</source>
        <translation>自動同步已關閉</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>未知</translation>
    </message>
    <message>
        <source>Server has been removed</source>
        <translation>伺服器已被刪除</translation>
    </message>
    <message>
        <source>You have not logged in to the server</source>
        <translation>您還沒有登入過此伺服器</translation>
    </message>
    <message>
        <source>You do not have permission to access this library</source>
        <translation>您沒有訪問此資料庫的權限</translation>
    </message>
    <message>
        <source>The storage space of the library owner has been used up</source>
        <translation>配額用盡了...</translation>
    </message>
    <message>
        <source>Remote service is not available</source>
        <translation>遠程服務器不可用</translation>
    </message>
    <message>
        <source>Access denied to service</source>
        <translation>請求服務時被拒絕</translation>
    </message>
    <message>
        <source>Internal data corrupted</source>
        <translation>內部數據損毀</translation>
    </message>
    <message>
        <source>Failed to start upload</source>
        <translation>無法開始上傳</translation>
    </message>
    <message>
        <source>Error occured in upload</source>
        <translation>上載時遭遇錯誤</translation>
    </message>
    <message>
        <source>Failed to start download</source>
        <translation>無法開始下載</translation>
    </message>
    <message>
        <source>Error occured in download</source>
        <translation>下載時遭遇錯誤</translation>
    </message>
    <message>
        <source>Library is damaged on server</source>
        <translation>資料庫在伺服器上的檔案已損毀</translation>
    </message>
    <message>
        <source>Conflict in merge</source>
        <translation>omg... 合併時候發生衝突</translation>
    </message>
    <message>
        <source>Server version is too old</source>
        <translation>伺服器版本過舊</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>遭遇未知錯誤</translation>
    </message>
    <message>
        <source>Permission denied on server. Please try resync the library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Network error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cannot resolve proxy address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cannot resolve server address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cannot connect to server</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to establish secure connection. Please check server SSL certificate</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Data transfer was interrupted. Please check network or firewall</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Data transfer timed out. Please check network or firewall</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unhandled http redirect from server. Please check server cofiguration</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Server error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Bad request</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Internal data corrupt on the client. Please try resync the library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Not enough memory</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to write data on the client. Please check disk space or folder permissions</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Storage quota full</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library deleted on server</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library damaged on server</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The storage quota has been used up</source>
        <translation>空間配額已用盡</translation>
    </message>
    <message>
        <source>Internal server error</source>
        <translation>內部伺服器錯誤</translation>
    </message>
    <message>
        <source>Your %1 client is too old</source>
        <translation>您%1 的客戶端版本過舊</translation>
    </message>
    <message>
        <source>Failed to sync this library</source>
        <translation>無法同步此資料庫</translation>
    </message>
    <message>
        <source>Files are locked by other application</source>
        <translation>檔案已被其他應用程式鎖住</translation>
    </message>
    <message>
        <source>Library is deleted on server</source>
        <translation>伺服器已刪除此資料庫</translation>
    </message>
    <message>
        <source>Error when accessing the local folder</source>
        <translation>在開啟本地資料夾時候遭遇錯誤</translation>
    </message>
    <message>
        <source>initializing...</source>
        <translation>初始化中... </translation>
    </message>
    <message>
        <source>Failed to index local files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to check server information</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to create local files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to merge local file changes</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Incorrect password. Please download again</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Internal error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>connecting server...</source>
        <translation>連接伺服器中...</translation>
    </message>
    <message>
        <source>indexing files...</source>
        <translation>索引檔案中...</translation>
    </message>
    <message>
        <source>Downloading file list...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Downloading files...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Creating folder...</source>
        <translation>建立資料夾中...</translation>
    </message>
    <message>
        <source>Merge file changes...</source>
        <translation>合併檔案衝突中...</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>完成</translation>
    </message>
    <message>
        <source>checking server info...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Canceling</source>
        <translation>取消中...</translation>
    </message>
    <message>
        <source>Canceled</source>
        <translation>已取消</translation>
    </message>
    <message>
        <source>SSL Error</source>
        <translation>SSL 安全證書錯誤</translation>
    </message>
    <message>
        <source>Network Error: %1</source>
        <translation>網路錯誤：%1</translation>
    </message>
    <message>
        <source>Server Error</source>
        <translation>伺服器錯誤</translation>
    </message>
    <message>
        <source>failed to open certs database</source>
        <translation>無法開啟證書數據庫</translation>
    </message>
    <message>
        <source>File &quot;%1&quot; doesn&apos;t exist in &quot;%2&quot;</source>
        <translation>檔案 &quot;%1&quot; 不存在於路徑 &quot;%2&quot; 中</translation>
    </message>
    <message>
        <source>%1 couldn&apos;t find an application to open file %2</source>
        <translation>%1 沒有能找到合適的應用程式開啟檔案 %2</translation>
    </message>
    <message>
        <source>Created library &quot;%1&quot;</source>
        <translation>建立新的資料庫 %1</translation>
    </message>
    <message>
        <source>Deleted library &quot;%1&quot;</source>
        <translation>刪除的資料庫 %1</translation>
    </message>
    <message>
        <source>Rename %1 to</source>
        <translation>將 %1 重命名為</translation>
    </message>
    <message>
        <source>Unable to download item &quot;%1&quot;</source>
        <translation>無法下載 &quot;%1&quot;</translation>
    </message>
    <message>
        <source>copy failed</source>
        <translation>複製失敗</translation>
    </message>
    <message>
        <source>Added</source>
        <translation>新增的</translation>
    </message>
    <message>
        <source>Deleted</source>
        <translation>刪除的</translation>
    </message>
    <message>
        <source>Removed</source>
        <translation>已被被刪除的</translation>
    </message>
    <message>
        <source>Modified</source>
        <translation>修改的</translation>
    </message>
    <message>
        <source>Renamed</source>
        <translation>重命名的</translation>
    </message>
    <message>
        <source>Added or modified</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Moved</source>
        <translation>移動的</translation>
    </message>
    <message>
        <source>Added directory</source>
        <translation>新增的資料夾</translation>
    </message>
    <message>
        <source>Removed directory</source>
        <translation>已被被刪除的資料夾</translation>
    </message>
    <message>
        <source>Renamed directory</source>
        <translation>重命名的資料夾</translation>
    </message>
    <message>
        <source>Moved directory</source>
        <translation>移動的資料夾</translation>
    </message>
    <message>
        <source>files</source>
        <translation>檔案</translation>
    </message>
    <message>
        <source>directories</source>
        <translation>目錄</translation>
    </message>
    <message>
        <source>and %1 more</source>
        <translation>還有 %1 等等</translation>
    </message>
    <message>
        <source>Reverted library to status at</source>
        <translation>恢復資料庫到狀態</translation>
    </message>
    <message>
        <source>Reverted file &quot;%1&quot; to status at %2.</source>
        <translation>恢復檔案 %1 到狀態 %2</translation>
    </message>
    <message>
        <source>Recovered deleted directory</source>
        <translation>恢復被刪除的資料夾</translation>
    </message>
    <message>
        <source>Changed library name or description</source>
        <translation>改變資料庫的名稱或者描述詞</translation>
    </message>
    <message>
        <source>Auto merge by %1 system</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Just now</source>
        <translation>就是現在</translation>
    </message>
    <message>
        <source>1 day ago</source>
        <translation>一天前</translation>
    </message>
    <message>
        <source>%1 days ago</source>
        <translation>%1 天前</translation>
    </message>
    <message>
        <source>1 hour ago</source>
        <translation>一小時前</translation>
    </message>
    <message>
        <source>%1 hours ago</source>
        <translation>%1 小時前</translation>
    </message>
    <message>
        <source>1 minute ago</source>
        <translation>一分鐘前</translation>
    </message>
    <message>
        <source>%1 minutes ago</source>
        <translation>%1 分鐘前</translation>
    </message>
    <message>
        <source>&lt;Not Part of Certificate&gt;</source>
        <translation>&lt;沒有包含在證書中&gt;</translation>
    </message>
    <message>
        <source>Found another running process of %1, kill it and start a new one?</source>
        <translation>發現已運行進程 %1， 殺死它並啟動新的進程？</translation>
    </message>
    <message>
        <source>Unable to start %1 due to the failure of shutting down the previous process</source>
        <translation>無法啟動 %1 因為無法關閉先前的進程</translation>
    </message>
    <message>
        <source>Sync this library to:</source>
        <translation>將此資料庫同步與：</translation>
    </message>
    <message>
        <source>Sync this folder to:</source>
        <translation>將此資料夾同步與：</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>資料夾</translation>
    </message>
    <message>
        <source>Readonly Folder</source>
        <translation>只讀資料夾</translation>
    </message>
    <message>
        <source>Document</source>
        <translation>檔案</translation>
    </message>
    <message>
        <source>PDF Document</source>
        <translation>PDF 檔案</translation>
    </message>
    <message>
        <source>Image File</source>
        <translation>圖像檔案</translation>
    </message>
    <message>
        <source>Text Document</source>
        <translation>文檔檔案</translation>
    </message>
    <message>
        <source>Audio File</source>
        <translation>音樂檔案</translation>
    </message>
    <message>
        <source>Video File</source>
        <translation>視頻檔案</translation>
    </message>
    <message>
        <source>Word Document</source>
        <translation>Word檔案</translation>
    </message>
    <message>
        <source>PowerPoint Document</source>
        <translation>PowerPoint檔案</translation>
    </message>
    <message>
        <source>Excel Document</source>
        <translation>Excel檔案</translation>
    </message>
    <message>
        <source>The path &quot;%1&quot; conflicts with system path</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The path &quot;%1&quot; conflicts with an existing library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>uploading file list</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File is locked by another application</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Folder is locked by another application</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File is locked by another user</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Path is invalid</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Error when indexing</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Path ends with space or period character</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Path contains invalid characters like &apos;|&apos; or &apos;:&apos;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>failed to open file cache database</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library name contains invalid characters such as &apos;:&apos;, &apos;*&apos;, &apos;|&apos;, &apos;?&apos;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Update to file denied by folder permission setting</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ReliablePostFileTask</name>
    <message>
        <source>File does not exist</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RepoDetailDialog</name>
    <message>
        <source>Library &quot;%1&quot;</source>
        <translation>資料庫 %1</translation>
    </message>
    <message>
        <source>This library is not downloaded yet</source>
        <translation>此資料庫還沒有被下載</translation>
    </message>
    <message>
        <source>Error: </source>
        <translation>錯誤：</translation>
    </message>
    <message>
        <source>every %1 seconds</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dialog</source>
        <translation>對話框</translation>
    </message>
    <message>
        <source>RepoIcon</source>
        <translation>資料庫圖示</translation>
    </message>
    <message>
        <source>RepoName</source>
        <translation>資料庫名稱</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>描述詞：</translation>
    </message>
    <message>
        <source>TextLabel</source>
        <translation>文本標簽：</translation>
    </message>
    <message>
        <source>Owner:</source>
        <translation>所有者：</translation>
    </message>
    <message>
        <source>Last Modified:</source>
        <translation>最後修改日期：</translation>
    </message>
    <message>
        <source>mtime</source>
        <translation>最後修改日期</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>檔案大小：</translation>
    </message>
    <message>
        <source>Local Path:</source>
        <translation>本地路徑：</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>狀態：</translation>
    </message>
    <message>
        <source>RepoStatus</source>
        <translation>資料庫狀態：</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>名稱：</translation>
    </message>
    <message>
        <source>Sync Interval:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Close</source>
        <translation>關閉</translation>
    </message>
</context>
<context>
    <name>RepoItemDelegate</name>
    <message>
        <source>, %1%2</source>
        <translation>, %1%2</translation>
    </message>
    <message>
        <source>, %1</source>
        <translation>, %1</translation>
    </message>
    <message>
        <source>This library has not been downloaded</source>
        <translation>此資料庫還沒有被下載</translation>
    </message>
</context>
<context>
    <name>RepoService</name>
    <message>
        <source>Unable to open file &quot;%1&quot; from nonexistent library &quot;%2&quot;</source>
        <translation>無法打開不存在資料庫 &quot;%2&quot; 中的文件 &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>RepoTreeModel</name>
    <message>
        <source>Recently Updated</source>
        <translation>最近更新</translation>
    </message>
    <message>
        <source>My Libraries</source>
        <translation>我的資料庫</translation>
    </message>
    <message>
        <source>Sub Libraries</source>
        <translation>子資料庫</translation>
    </message>
    <message>
        <source>Shared with me</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shared with all</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shared with groups</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Synced Libraries</source>
        <translation>已同步資料庫</translation>
    </message>
    <message>
        <source>sync initializing</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RepoTreeView</name>
    <message>
        <source>Disable auto sync</source>
        <translation>關閉自動同步</translation>
    </message>
    <message>
        <source>Enable auto sync</source>
        <translation>開啓自動同步</translation>
    </message>
    <message>
        <source>Show &amp;details</source>
        <translation>顯示資料 (&amp;D) </translation>
    </message>
    <message>
        <source>Show details of this library</source>
        <translation>顯示此資料庫的檔案</translation>
    </message>
    <message>
        <source>&amp;Sync this library</source>
        <translation>同步此資料庫 (&amp;S)</translation>
    </message>
    <message>
        <source>Sync this library</source>
        <translation>同步此資料庫</translation>
    </message>
    <message>
        <source>Recently Updated</source>
        <translation>最近更新</translation>
    </message>
    <message>
        <source>Sync &amp;now</source>
        <translation>立即同步 (&amp;N) </translation>
    </message>
    <message>
        <source>Sync this library immediately</source>
        <translation>立即同步此資料庫</translation>
    </message>
    <message>
        <source>&amp;Cancel download</source>
        <translation>取消下載(&amp;C)</translation>
    </message>
    <message>
        <source>Cancel download of this library</source>
        <translation>取消下載此資料庫</translation>
    </message>
    <message>
        <source>&amp;Open folder</source>
        <translation>開啟此資料夾(&amp;O)</translation>
    </message>
    <message>
        <source>open local folder</source>
        <translation>開啟本地資料夾</translation>
    </message>
    <message>
        <source>&amp;Open local folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Unsync</source>
        <translation>取消同步(&amp;U)</translation>
    </message>
    <message>
        <source>unsync this library</source>
        <translation>取消同步此資料庫</translation>
    </message>
    <message>
        <source>&amp;View on cloud</source>
        <translation>在瀏覽器中檢視(&amp;V)</translation>
    </message>
    <message>
        <source>view this library on seahub</source>
        <translation>在瀏覽器中檢視此資料庫</translation>
    </message>
    <message>
        <source>Share to user</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Share this library to a user</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Share to group</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Share this library to a group</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Open cloud file browser</source>
        <translation>開啟雲端檔案瀏覽器</translation>
    </message>
    <message>
        <source>open this library in embedded Cloud File Browser</source>
        <translation>用內置的雲端檔案瀏覽器檢視此資料庫</translation>
    </message>
    <message>
        <source>&amp;Leave share</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>leave share</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Resync this library</source>
        <translation>重新同步(&amp;R)</translation>
    </message>
    <message>
        <source>unsync and resync this library</source>
        <translation>取消同步此資料庫然後重新開啟同步</translation>
    </message>
    <message>
        <source>Set sync &amp;Interval</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>set sync interval for this library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure to unsync the library &quot;%1&quot;?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure to resync the library &quot;%1&quot;?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure to overwrite the file &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to unsync library &quot;%1&quot;</source>
        <translation>無法取消同步資料庫 %1</translation>
    </message>
    <message>
        <source>Are you sure you want to leave the share &quot;%1&quot;?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Leaving share failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to cancel this task:

 %1</source>
        <translation>無法取消這項任務：

%1</translation>
    </message>
    <message>
        <source>The download has been canceled</source>
        <translation>下載已被取消</translation>
    </message>
    <message>
        <source>You do not have permission to upload to this folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to overwrite file &quot;%1&quot; with itself</source>
        <translation>無法刪除用文件 &quot;%1&quot; 覆蓋自身</translation>
    </message>
    <message>
        <source>Unable to delete file &quot;%1&quot;</source>
        <translation>無法刪除檔案 &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Failed to upload file: %1</source>
        <translation>無法上傳檔案 &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Sync Interval (In seconds):</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Set Sync Internval For Library &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ReposTab</name>
    <message>
        <source>Search libraries</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>retry</source>
        <translation>重新嘗試</translation>
    </message>
    <message>
        <source>Failed to get libraries information&lt;br/&gt;Please %1</source>
        <translation>無法獲取資料庫檔案 &lt;br/&gt;
請 %1</translation>
    </message>
</context>
<context>
    <name>SeafileApiClient</name>
    <message>
        <source>&lt;b&gt;Warning:&lt;/b&gt; The ssl certificate of this server is not trusted, proceed anyway?</source>
        <translation>&lt;b&gt;警告：&lt;/b&gt; 伺服器的SSL證書不被信任，請問還需要繼續操作嗎？</translation>
    </message>
</context>
<context>
    <name>SeafileApplet</name>
    <message>
        <source>failed to add default account</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to initialize log: %s</source>
        <translation>無法初始化日誌: %s</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Yes</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SeafileLinkDialog</name>
    <message>
        <source>%1 Internal Link</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>複製到剪貼簿</translation>
    </message>
    <message>
        <source>%1 Web Link:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 Protocol Link:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OK</source>
        <translation>確認</translation>
    </message>
</context>
<context>
    <name>SeafileRpcClient</name>
    <message>
        <source>failed to load ccnet config dir %1</source>
        <translation>無法載入ccnet的配置目錄 %1</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>遭遇未知錯誤</translation>
    </message>
</context>
<context>
    <name>SeafileTrayIcon</name>
    <message>
        <source>Disable auto sync</source>
        <translation>取消自動同步</translation>
    </message>
    <message>
        <source>Enable auto sync</source>
        <translation>開啓自動同步</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>退出(&amp;Q)</translation>
    </message>
    <message>
        <source>Show main window</source>
        <translation>顯示主界面</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>設定檔</translation>
    </message>
    <message>
        <source>Open %1 &amp;folder</source>
        <translation>開啟%1 資料夾(&amp;F)</translation>
    </message>
    <message>
        <source>open %1 folder</source>
        <translation>開啟%1的資料夾</translation>
    </message>
    <message>
        <source>Open &amp;logs folder</source>
        <translation>開啟日誌資料夾(&amp;l) </translation>
    </message>
    <message>
        <source>Show file sync errors</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>關於我們(&amp;A)</translation>
    </message>
    <message>
        <source>Show the application&apos;s About box</source>
        <translation>顯示應用程式的關於對話框</translation>
    </message>
    <message>
        <source>&amp;Online help</source>
        <translation>在線幫助(&amp;O)</translation>
    </message>
    <message>
        <source>File</source>
        <translation>檔案</translation>
    </message>
    <message>
        <source>auto sync is disabled</source>
        <translation>自動同步已被禁用</translation>
    </message>
    <message>
        <source>Uploading</source>
        <translation>正在上傳</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>正在下載</translation>
    </message>
    <message>
        <source>open %1 log folder</source>
        <translation>開啟%1的日誌資料夾</translation>
    </message>
    <message>
        <source>open %1 online help</source>
        <translation>開啟%1的在線幫助</translation>
    </message>
    <message>
        <source>some servers not connected</source>
        <translation>到伺服器的連接部分運作中</translation>
    </message>
</context>
<context>
    <name>SearchResultListView</name>
    <message>
        <source>&amp;Show in folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show in folder</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SearchTab</name>
    <message>
        <source>Search files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>retry</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to search&lt;br/&gt;Please %1</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ServerStatusDialog</name>
    <message>
        <source>Servers connection status</source>
        <translation>到伺服器連接狀態</translation>
    </message>
    <message>
        <source>connected</source>
        <translation>已連接</translation>
    </message>
    <message>
        <source>disconnected</source>
        <translation>已斷開</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>對話框</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>關閉</translation>
    </message>
</context>
<context>
    <name>SetRepoPasswordDialog</name>
    <message>
        <source>Please provide the library password</source>
        <translation>請輸入資料庫的保護密碼</translation>
    </message>
    <message>
        <source>Provide the password for library %1</source>
        <translation>請輸入資料庫 %1 的保護密碼</translation>
    </message>
    <message>
        <source>Please enter the password</source>
        <translation>請輸入密碼</translation>
    </message>
    <message>
        <source>Incorrect password</source>
        <translation>無法理解的密碼</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>遭遇未知錯誤</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>對話框</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>確認</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Settings</source>
        <translation>設定檔</translation>
    </message>
    <message>
        <source>Auto start %1 after login</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Hide %1 Icon from the dock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>None</source>
        <translation>無代理</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>HTTP 代理</translation>
    </message>
    <message>
        <source>Socks5 Proxy</source>
        <translation>SOCKS5 代理</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You have changed languange. Restart to apply it?</source>
        <translation>您改變了使用的語言。現在重啓生效嗎？</translation>
    </message>
    <message>
        <source>The proxy host address can&apos;t be empty</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The proxy port is incorrect</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Proxy username can&apos;t be empty</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Proxy password can&apos;t be empty</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dialog</source>
        <translation>對話框</translation>
    </message>
    <message>
        <source>Hide main window when started</source>
        <translation>啟動時隱藏主界面</translation>
    </message>
    <message>
        <source>Notify when libraries are synchronized</source>
        <translation>當資料庫同步完成時提示</translation>
    </message>
    <message>
        <source>Enable sync temporary files of MSOffice/Libreoffice</source>
        <translation>同步Microsoft Office 和Libreoffice的臨時檔案</translation>
    </message>
    <message>
        <source>Download speed limit (KB/s):</source>
        <translation>下載速率 (KB/s)：</translation>
    </message>
    <message>
        <source>Upload speed limit (KB/s):</source>
        <translation>上載速率(KB/s)：</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>基礎</translation>
    </message>
    <message>
        <source>Do not automatically unsync a library</source>
        <translation>禁止自動取消同步資料庫</translation>
    </message>
    <message>
        <source>Do not automatically unsync a library when its local directory is removed or unaccessible for other reasons.</source>
        <translation>禁止當本地資料庫被刪除或無法訪問時，自動取消同步資料庫</translation>
    </message>
    <message>
        <source>Do not unsync a library when not found on server</source>
        <translation>禁止當資料庫無法在伺服器找到時，自動取消同步自理啊哭</translation>
    </message>
    <message>
        <source>Do not automatically unsync a library when it&apos;s not found on server</source>
        <translation>禁止當資料庫無法在伺服器找到時，自動取消同步自理啊哭</translation>
    </message>
    <message>
        <source>Enable FinderSync Extension</source>
        <translation>啟用 Finder的延伸功能</translation>
    </message>
    <message>
        <source>Enable Explorer Extension</source>
        <translation>啟用檔案瀏覽器的延伸功能</translation>
    </message>
    <message>
        <source>Check for updates automatically</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Do not verify server certificate in HTTPS syncing</source>
        <translation>在HTTPS 同步過程中無法認證伺服器的證書</translation>
    </message>
    <message>
        <source>Enable syncing with an existing folder with a different name</source>
        <translation>開啟與已存在的不同文件名的資料夾同步的選項</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>高級</translation>
    </message>
    <message>
        <source>Language (need restart)</source>
        <translation>語言 (需要重啓)</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>語言</translation>
    </message>
    <message>
        <source>Proxy Type:</source>
        <translation>代理類型：</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>主機地址：</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>端口：</translation>
    </message>
    <message>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>用戶名：</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>密碼：</translation>
    </message>
    <message>
        <source>Proxy server requires a password</source>
        <translation>代理伺服器需要密碼</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>網路</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>確認</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
</context>
<context>
    <name>SharedItemDelegate</name>
    <message>
        <source>Read Write</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Read Only</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remove Share</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SharedItemsTableModel</name>
    <message>
        <source>Click to edit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Created by %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Read Write</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Read Only</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Group</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>User</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Permission</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The previous operation is still in progres</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SharedLinkDialog</name>
    <message>
        <source>Share Link</source>
        <translation>分享連接</translation>
    </message>
    <message>
        <source>Share link:</source>
        <translation>分享連接:</translation>
    </message>
    <message>
        <source>Direct Download</source>
        <translation>直接下載</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>複製到剪貼簿</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>確認</translation>
    </message>
</context>
<context>
    <name>ShibLoginDialog</name>
    <message>
        <source>Login with Shibboleth</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to save current account</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SslConfirmDialog</name>
    <message>
        <source>Untrusted Connection</source>
        <translation>不被信任的連接</translation>
    </message>
    <message>
        <source>%1 uses an invalid security certificate. The connection may be insecure. Do you want to continue?</source>
        <translation>%1 使用了未認證的安全證書。此次連接可能是不安全的，請問還繼續嗎？</translation>
    </message>
    <message>
        <source>Current RSA key fingerprint is %1</source>
        <translation>目前證書 RSA 指紋是 %1</translation>
    </message>
    <message>
        <source>Previous RSA key fingerprint is %1</source>
        <translation>先前證書 RSA 指紋是 %1</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>對話框</translation>
    </message>
    <message>
        <source>Remember my choice</source>
        <translation>記住我的選項</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>好</translation>
    </message>
    <message>
        <source>No</source>
        <translation>不好</translation>
    </message>
</context>
<context>
    <name>StarredFilesListView</name>
    <message>
        <source>&amp;Open</source>
        <translation>開啟(&amp;O)</translation>
    </message>
    <message>
        <source>Open this file</source>
        <translation>開啟此檔案</translation>
    </message>
    <message>
        <source>view on &amp;Web</source>
        <translation>在瀏覽器中檢視(&amp;W)</translation>
    </message>
    <message>
        <source>view this file on website</source>
        <translation>在瀏覽器中檢視此檔案</translation>
    </message>
</context>
<context>
    <name>StarredFilesTab</name>
    <message>
        <source>retry</source>
        <translation>重新嘗試</translation>
    </message>
    <message>
        <source>Failed to get starred files information&lt;br/&gt;Please %1</source>
        <translation>無法獲取標示檔案的訊息&lt;br/&gt;請 %1</translation>
    </message>
    <message>
        <source>You have no starred files yet.</source>
        <translation>您沒有標示任何檔案</translation>
    </message>
</context>
<context>
    <name>SyncErrorsDialog</name>
    <message>
        <source>File Sync Errors</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No sync errors.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SyncErrorsTableModel</name>
    <message>
        <source>Double click to open the library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Path</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Time</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TwoFactorDialog</name>
    <message>
        <source>Enter the two factor authentication token</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Two Factor Authentication</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please enter the two factor authentication token</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dialog</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>mText</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remember this device</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UninstallHelperDialog</name>
    <message>
        <source>Uninstall %1</source>
        <translation>移除 %1</translation>
    </message>
    <message>
        <source>Do you want to remove the %1 account information?</source>
        <translation>您想刪除 帳號 %1 的訊息？</translation>
    </message>
    <message>
        <source>Removing account information...</source>
        <translation>正在刪除帳號訊息...</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>對話框</translation>
    </message>
    <message>
        <source>text</source>
        <translation>文本</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>好</translation>
    </message>
    <message>
        <source>No</source>
        <translation>不好</translation>
    </message>
</context>
</TS>